@@ -13,28 +13,28 @@ class FindPronouns(BaseObject):
     __alphabet = [(chr(ord('a') + i)) for i in range(26)]
 
     _d_pronouns = {
-        "1": [
-            "i",
-            "me",
-            "my",
-            "mine",
-            "myself",
-            "we",
-            "us",
-            "our",
-            "ourselves"
+        '1': [
+            'i',
+            'me',
+            'my',
+            'mine',
+            'myself',
+            'we',
+            'us',
+            'our',
+            'ourselves'
         ],
-        "2": [
-            "you"
+        '2': [
+            'you'
         ],
-        "3": [
-            "she",
-            "her",
-            "he",
-            "him",
-            "it",
-            "they",
-            "them"
+        '3': [
+            'she',
+            'her',
+            'he',
+            'him',
+            'it',
+            'they',
+            'them'
         ]
     }
 
